# API Reference <a name="API Reference" id="api-reference"></a>


## Structs <a name="Structs" id="Structs"></a>

### AccountInfo <a name="AccountInfo" id="@wasend/core.AccountInfo"></a>

Account information structure.

#### Initializer <a name="Initializer" id="@wasend/core.AccountInfo.Initializer"></a>

```typescript
import { AccountInfo } from '@wasend/core'

const accountInfo: AccountInfo = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.AccountInfo.property.id">id</a></code> | <code>string</code> | Account ID. |
| <code><a href="#@wasend/core.AccountInfo.property.name">name</a></code> | <code>string</code> | Account name. |
| <code><a href="#@wasend/core.AccountInfo.property.plan">plan</a></code> | <code>string</code> | Account plan. |

---

##### `id`<sup>Required</sup> <a name="id" id="@wasend/core.AccountInfo.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Account ID.

---

##### `name`<sup>Required</sup> <a name="name" id="@wasend/core.AccountInfo.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Account name.

---

##### `plan`<sup>Required</sup> <a name="plan" id="@wasend/core.AccountInfo.property.plan"></a>

```typescript
public readonly plan: string;
```

- *Type:* string

Account plan.

---

### ApiResponse <a name="ApiResponse" id="@wasend/core.ApiResponse"></a>

Response from API calls.

#### Initializer <a name="Initializer" id="@wasend/core.ApiResponse.Initializer"></a>

```typescript
import { ApiResponse } from '@wasend/core'

const apiResponse: ApiResponse = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.ApiResponse.property.success">success</a></code> | <code>boolean</code> | Whether the request was successful. |
| <code><a href="#@wasend/core.ApiResponse.property.data">data</a></code> | <code>any</code> | The response data (if successful). |
| <code><a href="#@wasend/core.ApiResponse.property.error">error</a></code> | <code>string</code> | Error message if the request failed. |

---

##### `success`<sup>Required</sup> <a name="success" id="@wasend/core.ApiResponse.property.success"></a>

```typescript
public readonly success: boolean;
```

- *Type:* boolean

Whether the request was successful.

---

##### `data`<sup>Optional</sup> <a name="data" id="@wasend/core.ApiResponse.property.data"></a>

```typescript
public readonly data: any;
```

- *Type:* any

The response data (if successful).

---

##### `error`<sup>Optional</sup> <a name="error" id="@wasend/core.ApiResponse.property.error"></a>

```typescript
public readonly error: string;
```

- *Type:* string

Error message if the request failed.

---

### DownstreamInfo <a name="DownstreamInfo" id="@wasend/core.DownstreamInfo"></a>

Downstream connection information.

#### Initializer <a name="Initializer" id="@wasend/core.DownstreamInfo.Initializer"></a>

```typescript
import { DownstreamInfo } from '@wasend/core'

const downstreamInfo: DownstreamInfo = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.DownstreamInfo.property.config">config</a></code> | <code><a href="#@wasend/core.SessionConfig">SessionConfig</a></code> | Configuration for the downstream connection. |
| <code><a href="#@wasend/core.DownstreamInfo.property.engine">engine</a></code> | <code><a href="#@wasend/core.EngineStatus">EngineStatus</a></code> | Engine status information. |
| <code><a href="#@wasend/core.DownstreamInfo.property.name">name</a></code> | <code>string</code> | Name of the downstream connection. |
| <code><a href="#@wasend/core.DownstreamInfo.property.status">status</a></code> | <code>string</code> | Status of the downstream connection. |

---

##### `config`<sup>Required</sup> <a name="config" id="@wasend/core.DownstreamInfo.property.config"></a>

```typescript
public readonly config: SessionConfig;
```

- *Type:* <a href="#@wasend/core.SessionConfig">SessionConfig</a>

Configuration for the downstream connection.

---

##### `engine`<sup>Required</sup> <a name="engine" id="@wasend/core.DownstreamInfo.property.engine"></a>

```typescript
public readonly engine: EngineStatus;
```

- *Type:* <a href="#@wasend/core.EngineStatus">EngineStatus</a>

Engine status information.

---

##### `name`<sup>Required</sup> <a name="name" id="@wasend/core.DownstreamInfo.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the downstream connection.

---

##### `status`<sup>Required</sup> <a name="status" id="@wasend/core.DownstreamInfo.property.status"></a>

```typescript
public readonly status: string;
```

- *Type:* string

Status of the downstream connection.

---

### EngineStatus <a name="EngineStatus" id="@wasend/core.EngineStatus"></a>

Engine status information.

#### Initializer <a name="Initializer" id="@wasend/core.EngineStatus.Initializer"></a>

```typescript
import { EngineStatus } from '@wasend/core'

const engineStatus: EngineStatus = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.EngineStatus.property.gows">gows</a></code> | <code><a href="#@wasend/core.GowsStatus">GowsStatus</a></code> | GoWS status. |
| <code><a href="#@wasend/core.EngineStatus.property.grpc">grpc</a></code> | <code><a href="#@wasend/core.GrpcStatus">GrpcStatus</a></code> | gRPC status. |

---

##### `gows`<sup>Required</sup> <a name="gows" id="@wasend/core.EngineStatus.property.gows"></a>

```typescript
public readonly gows: GowsStatus;
```

- *Type:* <a href="#@wasend/core.GowsStatus">GowsStatus</a>

GoWS status.

---

##### `grpc`<sup>Required</sup> <a name="grpc" id="@wasend/core.EngineStatus.property.grpc"></a>

```typescript
public readonly grpc: GrpcStatus;
```

- *Type:* <a href="#@wasend/core.GrpcStatus">GrpcStatus</a>

gRPC status.

---

### GetAllSessionsResponse <a name="GetAllSessionsResponse" id="@wasend/core.GetAllSessionsResponse"></a>

Response wrapper for getAllSessions.

#### Initializer <a name="Initializer" id="@wasend/core.GetAllSessionsResponse.Initializer"></a>

```typescript
import { GetAllSessionsResponse } from '@wasend/core'

const getAllSessionsResponse: GetAllSessionsResponse = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GetAllSessionsResponse.property.sessions">sessions</a></code> | <code><a href="#@wasend/core.SessionListItem">SessionListItem</a>[]</code> | Array of sessions. |

---

##### `sessions`<sup>Required</sup> <a name="sessions" id="@wasend/core.GetAllSessionsResponse.property.sessions"></a>

```typescript
public readonly sessions: SessionListItem[];
```

- *Type:* <a href="#@wasend/core.SessionListItem">SessionListItem</a>[]

Array of sessions.

---

### GowsStatus <a name="GowsStatus" id="@wasend/core.GowsStatus"></a>

#### Initializer <a name="Initializer" id="@wasend/core.GowsStatus.Initializer"></a>

```typescript
import { GowsStatus } from '@wasend/core'

const gowsStatus: GowsStatus = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GowsStatus.property.connected">connected</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.GowsStatus.property.found">found</a></code> | <code>boolean</code> | *No description.* |

---

##### `connected`<sup>Required</sup> <a name="connected" id="@wasend/core.GowsStatus.property.connected"></a>

```typescript
public readonly connected: boolean;
```

- *Type:* boolean

---

##### `found`<sup>Required</sup> <a name="found" id="@wasend/core.GowsStatus.property.found"></a>

```typescript
public readonly found: boolean;
```

- *Type:* boolean

---

### GrpcStatus <a name="GrpcStatus" id="@wasend/core.GrpcStatus"></a>

#### Initializer <a name="Initializer" id="@wasend/core.GrpcStatus.Initializer"></a>

```typescript
import { GrpcStatus } from '@wasend/core'

const grpcStatus: GrpcStatus = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.GrpcStatus.property.client">client</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@wasend/core.GrpcStatus.property.stream">stream</a></code> | <code>string</code> | *No description.* |

---

##### `client`<sup>Required</sup> <a name="client" id="@wasend/core.GrpcStatus.property.client"></a>

```typescript
public readonly client: string;
```

- *Type:* string

---

##### `stream`<sup>Required</sup> <a name="stream" id="@wasend/core.GrpcStatus.property.stream"></a>

```typescript
public readonly stream: string;
```

- *Type:* string

---

### Message <a name="Message" id="@wasend/core.Message"></a>

Message data structure.

#### Initializer <a name="Initializer" id="@wasend/core.Message.Initializer"></a>

```typescript
import { Message } from '@wasend/core'

const message: Message = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.Message.property.content">content</a></code> | <code>string</code> | The content of the message. |
| <code><a href="#@wasend/core.Message.property.id">id</a></code> | <code>string</code> | Unique identifier for the message. |
| <code><a href="#@wasend/core.Message.property.sentAt">sentAt</a></code> | <code>string</code> | Timestamp when the message was sent (ISO string). |
| <code><a href="#@wasend/core.Message.property.status">status</a></code> | <code>string</code> | Message status. |
| <code><a href="#@wasend/core.Message.property.to">to</a></code> | <code>string</code> | The recipient of the message. |

---

##### `content`<sup>Required</sup> <a name="content" id="@wasend/core.Message.property.content"></a>

```typescript
public readonly content: string;
```

- *Type:* string

The content of the message.

---

##### `id`<sup>Required</sup> <a name="id" id="@wasend/core.Message.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

Unique identifier for the message.

---

##### `sentAt`<sup>Required</sup> <a name="sentAt" id="@wasend/core.Message.property.sentAt"></a>

```typescript
public readonly sentAt: string;
```

- *Type:* string

Timestamp when the message was sent (ISO string).

---

##### `status`<sup>Required</sup> <a name="status" id="@wasend/core.Message.property.status"></a>

```typescript
public readonly status: string;
```

- *Type:* string

Message status.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.Message.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient of the message.

---

### MessageRequest <a name="MessageRequest" id="@wasend/core.MessageRequest"></a>

Message request structure.

#### Initializer <a name="Initializer" id="@wasend/core.MessageRequest.Initializer"></a>

```typescript
import { MessageRequest } from '@wasend/core'

const messageRequest: MessageRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.MessageRequest.property.content">content</a></code> | <code>string</code> | The content of the message. |
| <code><a href="#@wasend/core.MessageRequest.property.to">to</a></code> | <code>string</code> | The recipient of the message. |

---

##### `content`<sup>Required</sup> <a name="content" id="@wasend/core.MessageRequest.property.content"></a>

```typescript
public readonly content: string;
```

- *Type:* string

The content of the message.

---

##### `to`<sup>Required</sup> <a name="to" id="@wasend/core.MessageRequest.property.to"></a>

```typescript
public readonly to: string;
```

- *Type:* string

The recipient of the message.

---

### NowebConfig <a name="NowebConfig" id="@wasend/core.NowebConfig"></a>

#### Initializer <a name="Initializer" id="@wasend/core.NowebConfig.Initializer"></a>

```typescript
import { NowebConfig } from '@wasend/core'

const nowebConfig: NowebConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.NowebConfig.property.markOnline">markOnline</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.NowebConfig.property.store">store</a></code> | <code><a href="#@wasend/core.NowebStoreConfig">NowebStoreConfig</a></code> | *No description.* |

---

##### `markOnline`<sup>Required</sup> <a name="markOnline" id="@wasend/core.NowebConfig.property.markOnline"></a>

```typescript
public readonly markOnline: boolean;
```

- *Type:* boolean

---

##### `store`<sup>Required</sup> <a name="store" id="@wasend/core.NowebConfig.property.store"></a>

```typescript
public readonly store: NowebStoreConfig;
```

- *Type:* <a href="#@wasend/core.NowebStoreConfig">NowebStoreConfig</a>

---

### NowebStoreConfig <a name="NowebStoreConfig" id="@wasend/core.NowebStoreConfig"></a>

#### Initializer <a name="Initializer" id="@wasend/core.NowebStoreConfig.Initializer"></a>

```typescript
import { NowebStoreConfig } from '@wasend/core'

const nowebStoreConfig: NowebStoreConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.NowebStoreConfig.property.enabled">enabled</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.NowebStoreConfig.property.fullSync">fullSync</a></code> | <code>boolean</code> | *No description.* |

---

##### `enabled`<sup>Required</sup> <a name="enabled" id="@wasend/core.NowebStoreConfig.property.enabled"></a>

```typescript
public readonly enabled: boolean;
```

- *Type:* boolean

---

##### `fullSync`<sup>Required</sup> <a name="fullSync" id="@wasend/core.NowebStoreConfig.property.fullSync"></a>

```typescript
public readonly fullSync: boolean;
```

- *Type:* boolean

---

### QRCodeResponse <a name="QRCodeResponse" id="@wasend/core.QRCodeResponse"></a>

QR code response.

#### Initializer <a name="Initializer" id="@wasend/core.QRCodeResponse.Initializer"></a>

```typescript
import { QRCodeResponse } from '@wasend/core'

const qRCodeResponse: QRCodeResponse = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.QRCodeResponse.property.data">data</a></code> | <code>string</code> | QR code data. |

---

##### `data`<sup>Required</sup> <a name="data" id="@wasend/core.QRCodeResponse.property.data"></a>

```typescript
public readonly data: string;
```

- *Type:* string

QR code data.

---

### Session <a name="Session" id="@wasend/core.Session"></a>

Session information from createSession and other operations.

#### Initializer <a name="Initializer" id="@wasend/core.Session.Initializer"></a>

```typescript
import { Session } from '@wasend/core'

const session: Session = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.Session.property.createdAt">createdAt</a></code> | <code>string</code> | Creation timestamp. |
| <code><a href="#@wasend/core.Session.property.enableAccountProtection">enableAccountProtection</a></code> | <code>boolean</code> | Session configuration flags. |
| <code><a href="#@wasend/core.Session.property.enableMessageLogging">enableMessageLogging</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.Session.property.enableWebhook">enableWebhook</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.Session.property.id">id</a></code> | <code>string</code> | MongoDB ID of the session. |
| <code><a href="#@wasend/core.Session.property.phoneNumber">phoneNumber</a></code> | <code>string</code> | Phone number associated with the session. |
| <code><a href="#@wasend/core.Session.property.sessionName">sessionName</a></code> | <code>string</code> | Name of the session. |
| <code><a href="#@wasend/core.Session.property.uniqueSessionId">uniqueSessionId</a></code> | <code>string</code> | Unique session identifier. |
| <code><a href="#@wasend/core.Session.property.updatedAt">updatedAt</a></code> | <code>string</code> | Last update timestamp. |
| <code><a href="#@wasend/core.Session.property.userId">userId</a></code> | <code>string</code> | User ID who owns the session. |
| <code><a href="#@wasend/core.Session.property.webhookUrl">webhookUrl</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@wasend/core.Session.property.config">config</a></code> | <code><a href="#@wasend/core.SessionConfig">SessionConfig</a></code> | Session configuration. |
| <code><a href="#@wasend/core.Session.property.engine">engine</a></code> | <code><a href="#@wasend/core.EngineStatus">EngineStatus</a></code> | Engine status information. |
| <code><a href="#@wasend/core.Session.property.name">name</a></code> | <code>string</code> | Name of the session. |
| <code><a href="#@wasend/core.Session.property.status">status</a></code> | <code>string</code> | Current status of the session. |

---

##### `createdAt`<sup>Required</sup> <a name="createdAt" id="@wasend/core.Session.property.createdAt"></a>

```typescript
public readonly createdAt: string;
```

- *Type:* string

Creation timestamp.

---

##### `enableAccountProtection`<sup>Required</sup> <a name="enableAccountProtection" id="@wasend/core.Session.property.enableAccountProtection"></a>

```typescript
public readonly enableAccountProtection: boolean;
```

- *Type:* boolean

Session configuration flags.

---

##### `enableMessageLogging`<sup>Required</sup> <a name="enableMessageLogging" id="@wasend/core.Session.property.enableMessageLogging"></a>

```typescript
public readonly enableMessageLogging: boolean;
```

- *Type:* boolean

---

##### `enableWebhook`<sup>Required</sup> <a name="enableWebhook" id="@wasend/core.Session.property.enableWebhook"></a>

```typescript
public readonly enableWebhook: boolean;
```

- *Type:* boolean

---

##### `id`<sup>Required</sup> <a name="id" id="@wasend/core.Session.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

MongoDB ID of the session.

---

##### `phoneNumber`<sup>Required</sup> <a name="phoneNumber" id="@wasend/core.Session.property.phoneNumber"></a>

```typescript
public readonly phoneNumber: string;
```

- *Type:* string

Phone number associated with the session.

---

##### `sessionName`<sup>Required</sup> <a name="sessionName" id="@wasend/core.Session.property.sessionName"></a>

```typescript
public readonly sessionName: string;
```

- *Type:* string

Name of the session.

---

##### `uniqueSessionId`<sup>Required</sup> <a name="uniqueSessionId" id="@wasend/core.Session.property.uniqueSessionId"></a>

```typescript
public readonly uniqueSessionId: string;
```

- *Type:* string

Unique session identifier.

---

##### `updatedAt`<sup>Required</sup> <a name="updatedAt" id="@wasend/core.Session.property.updatedAt"></a>

```typescript
public readonly updatedAt: string;
```

- *Type:* string

Last update timestamp.

---

##### `userId`<sup>Required</sup> <a name="userId" id="@wasend/core.Session.property.userId"></a>

```typescript
public readonly userId: string;
```

- *Type:* string

User ID who owns the session.

---

##### `webhookUrl`<sup>Optional</sup> <a name="webhookUrl" id="@wasend/core.Session.property.webhookUrl"></a>

```typescript
public readonly webhookUrl: string;
```

- *Type:* string

---

##### `config`<sup>Required</sup> <a name="config" id="@wasend/core.Session.property.config"></a>

```typescript
public readonly config: SessionConfig;
```

- *Type:* <a href="#@wasend/core.SessionConfig">SessionConfig</a>

Session configuration.

---

##### `engine`<sup>Required</sup> <a name="engine" id="@wasend/core.Session.property.engine"></a>

```typescript
public readonly engine: EngineStatus;
```

- *Type:* <a href="#@wasend/core.EngineStatus">EngineStatus</a>

Engine status information.

---

##### `name`<sup>Required</sup> <a name="name" id="@wasend/core.Session.property.name"></a>

```typescript
public readonly name: string;
```

- *Type:* string

Name of the session.

---

##### `status`<sup>Required</sup> <a name="status" id="@wasend/core.Session.property.status"></a>

```typescript
public readonly status: string;
```

- *Type:* string

Current status of the session.

---

### SessionConfig <a name="SessionConfig" id="@wasend/core.SessionConfig"></a>

Session configuration.

#### Initializer <a name="Initializer" id="@wasend/core.SessionConfig.Initializer"></a>

```typescript
import { SessionConfig } from '@wasend/core'

const sessionConfig: SessionConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SessionConfig.property.debug">debug</a></code> | <code>boolean</code> | Debug mode. |
| <code><a href="#@wasend/core.SessionConfig.property.metadata">metadata</a></code> | <code><a href="#@wasend/core.SessionMetadata">SessionMetadata</a></code> | User metadata. |
| <code><a href="#@wasend/core.SessionConfig.property.noweb">noweb</a></code> | <code><a href="#@wasend/core.NowebConfig">NowebConfig</a></code> | Noweb configuration. |
| <code><a href="#@wasend/core.SessionConfig.property.proxy">proxy</a></code> | <code>any</code> | Proxy configuration. |
| <code><a href="#@wasend/core.SessionConfig.property.webhooks">webhooks</a></code> | <code>any[]</code> | Webhook configurations. |

---

##### `debug`<sup>Required</sup> <a name="debug" id="@wasend/core.SessionConfig.property.debug"></a>

```typescript
public readonly debug: boolean;
```

- *Type:* boolean

Debug mode.

---

##### `metadata`<sup>Required</sup> <a name="metadata" id="@wasend/core.SessionConfig.property.metadata"></a>

```typescript
public readonly metadata: SessionMetadata;
```

- *Type:* <a href="#@wasend/core.SessionMetadata">SessionMetadata</a>

User metadata.

---

##### `noweb`<sup>Required</sup> <a name="noweb" id="@wasend/core.SessionConfig.property.noweb"></a>

```typescript
public readonly noweb: NowebConfig;
```

- *Type:* <a href="#@wasend/core.NowebConfig">NowebConfig</a>

Noweb configuration.

---

##### `proxy`<sup>Required</sup> <a name="proxy" id="@wasend/core.SessionConfig.property.proxy"></a>

```typescript
public readonly proxy: any;
```

- *Type:* any

Proxy configuration.

---

##### `webhooks`<sup>Required</sup> <a name="webhooks" id="@wasend/core.SessionConfig.property.webhooks"></a>

```typescript
public readonly webhooks: any[];
```

- *Type:* any[]

Webhook configurations.

---

### SessionCreateRequest <a name="SessionCreateRequest" id="@wasend/core.SessionCreateRequest"></a>

Session creation request body.

#### Initializer <a name="Initializer" id="@wasend/core.SessionCreateRequest.Initializer"></a>

```typescript
import { SessionCreateRequest } from '@wasend/core'

const sessionCreateRequest: SessionCreateRequest = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SessionCreateRequest.property.phoneNumber">phoneNumber</a></code> | <code>string</code> | Phone number for the WhatsApp session. |
| <code><a href="#@wasend/core.SessionCreateRequest.property.sessionName">sessionName</a></code> | <code>string</code> | Name of the session. |
| <code><a href="#@wasend/core.SessionCreateRequest.property.enableAccountProtection">enableAccountProtection</a></code> | <code>boolean</code> | Enable account protection features. |
| <code><a href="#@wasend/core.SessionCreateRequest.property.enableMessageLogging">enableMessageLogging</a></code> | <code>boolean</code> | Enable message logging. |
| <code><a href="#@wasend/core.SessionCreateRequest.property.enableWebhook">enableWebhook</a></code> | <code>boolean</code> | Enable webhook notifications. |
| <code><a href="#@wasend/core.SessionCreateRequest.property.webhookUrl">webhookUrl</a></code> | <code>string</code> | Webhook URL for notifications Required if enableWebhook is true. |

---

##### `phoneNumber`<sup>Required</sup> <a name="phoneNumber" id="@wasend/core.SessionCreateRequest.property.phoneNumber"></a>

```typescript
public readonly phoneNumber: string;
```

- *Type:* string

Phone number for the WhatsApp session.

---

##### `sessionName`<sup>Required</sup> <a name="sessionName" id="@wasend/core.SessionCreateRequest.property.sessionName"></a>

```typescript
public readonly sessionName: string;
```

- *Type:* string

Name of the session.

---

##### `enableAccountProtection`<sup>Optional</sup> <a name="enableAccountProtection" id="@wasend/core.SessionCreateRequest.property.enableAccountProtection"></a>

```typescript
public readonly enableAccountProtection: boolean;
```

- *Type:* boolean
- *Default:* false

Enable account protection features.

---

##### `enableMessageLogging`<sup>Optional</sup> <a name="enableMessageLogging" id="@wasend/core.SessionCreateRequest.property.enableMessageLogging"></a>

```typescript
public readonly enableMessageLogging: boolean;
```

- *Type:* boolean
- *Default:* false

Enable message logging.

---

##### `enableWebhook`<sup>Optional</sup> <a name="enableWebhook" id="@wasend/core.SessionCreateRequest.property.enableWebhook"></a>

```typescript
public readonly enableWebhook: boolean;
```

- *Type:* boolean
- *Default:* false

Enable webhook notifications.

---

##### `webhookUrl`<sup>Optional</sup> <a name="webhookUrl" id="@wasend/core.SessionCreateRequest.property.webhookUrl"></a>

```typescript
public readonly webhookUrl: string;
```

- *Type:* string

Webhook URL for notifications Required if enableWebhook is true.

---

### SessionDetails <a name="SessionDetails" id="@wasend/core.SessionDetails"></a>

Session details.

#### Initializer <a name="Initializer" id="@wasend/core.SessionDetails.Initializer"></a>

```typescript
import { SessionDetails } from '@wasend/core'

const sessionDetails: SessionDetails = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SessionDetails.property.createdAt">createdAt</a></code> | <code>string</code> | Creation timestamp. |
| <code><a href="#@wasend/core.SessionDetails.property.enableAccountProtection">enableAccountProtection</a></code> | <code>boolean</code> | Session configuration flags. |
| <code><a href="#@wasend/core.SessionDetails.property.enableMessageLogging">enableMessageLogging</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.SessionDetails.property.enableWebhook">enableWebhook</a></code> | <code>boolean</code> | *No description.* |
| <code><a href="#@wasend/core.SessionDetails.property.id">id</a></code> | <code>string</code> | MongoDB ID of the session. |
| <code><a href="#@wasend/core.SessionDetails.property.phoneNumber">phoneNumber</a></code> | <code>string</code> | Phone number associated with the session. |
| <code><a href="#@wasend/core.SessionDetails.property.sessionName">sessionName</a></code> | <code>string</code> | Name of the session. |
| <code><a href="#@wasend/core.SessionDetails.property.uniqueSessionId">uniqueSessionId</a></code> | <code>string</code> | Unique session identifier. |
| <code><a href="#@wasend/core.SessionDetails.property.updatedAt">updatedAt</a></code> | <code>string</code> | Last update timestamp. |
| <code><a href="#@wasend/core.SessionDetails.property.userId">userId</a></code> | <code>string</code> | User ID who owns the session. |
| <code><a href="#@wasend/core.SessionDetails.property.webhookUrl">webhookUrl</a></code> | <code>string</code> | *No description.* |

---

##### `createdAt`<sup>Required</sup> <a name="createdAt" id="@wasend/core.SessionDetails.property.createdAt"></a>

```typescript
public readonly createdAt: string;
```

- *Type:* string

Creation timestamp.

---

##### `enableAccountProtection`<sup>Required</sup> <a name="enableAccountProtection" id="@wasend/core.SessionDetails.property.enableAccountProtection"></a>

```typescript
public readonly enableAccountProtection: boolean;
```

- *Type:* boolean

Session configuration flags.

---

##### `enableMessageLogging`<sup>Required</sup> <a name="enableMessageLogging" id="@wasend/core.SessionDetails.property.enableMessageLogging"></a>

```typescript
public readonly enableMessageLogging: boolean;
```

- *Type:* boolean

---

##### `enableWebhook`<sup>Required</sup> <a name="enableWebhook" id="@wasend/core.SessionDetails.property.enableWebhook"></a>

```typescript
public readonly enableWebhook: boolean;
```

- *Type:* boolean

---

##### `id`<sup>Required</sup> <a name="id" id="@wasend/core.SessionDetails.property.id"></a>

```typescript
public readonly id: string;
```

- *Type:* string

MongoDB ID of the session.

---

##### `phoneNumber`<sup>Required</sup> <a name="phoneNumber" id="@wasend/core.SessionDetails.property.phoneNumber"></a>

```typescript
public readonly phoneNumber: string;
```

- *Type:* string

Phone number associated with the session.

---

##### `sessionName`<sup>Required</sup> <a name="sessionName" id="@wasend/core.SessionDetails.property.sessionName"></a>

```typescript
public readonly sessionName: string;
```

- *Type:* string

Name of the session.

---

##### `uniqueSessionId`<sup>Required</sup> <a name="uniqueSessionId" id="@wasend/core.SessionDetails.property.uniqueSessionId"></a>

```typescript
public readonly uniqueSessionId: string;
```

- *Type:* string

Unique session identifier.

---

##### `updatedAt`<sup>Required</sup> <a name="updatedAt" id="@wasend/core.SessionDetails.property.updatedAt"></a>

```typescript
public readonly updatedAt: string;
```

- *Type:* string

Last update timestamp.

---

##### `userId`<sup>Required</sup> <a name="userId" id="@wasend/core.SessionDetails.property.userId"></a>

```typescript
public readonly userId: string;
```

- *Type:* string

User ID who owns the session.

---

##### `webhookUrl`<sup>Optional</sup> <a name="webhookUrl" id="@wasend/core.SessionDetails.property.webhookUrl"></a>

```typescript
public readonly webhookUrl: string;
```

- *Type:* string

---

### SessionListItem <a name="SessionListItem" id="@wasend/core.SessionListItem"></a>

Session information from getAllSessions.

#### Initializer <a name="Initializer" id="@wasend/core.SessionListItem.Initializer"></a>

```typescript
import { SessionListItem } from '@wasend/core'

const sessionListItem: SessionListItem = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SessionListItem.property.downstream">downstream</a></code> | <code><a href="#@wasend/core.DownstreamInfo">DownstreamInfo</a></code> | Downstream connection information. |
| <code><a href="#@wasend/core.SessionListItem.property.session">session</a></code> | <code><a href="#@wasend/core.SessionDetails">SessionDetails</a></code> | Session details. |

---

##### `downstream`<sup>Required</sup> <a name="downstream" id="@wasend/core.SessionListItem.property.downstream"></a>

```typescript
public readonly downstream: DownstreamInfo;
```

- *Type:* <a href="#@wasend/core.DownstreamInfo">DownstreamInfo</a>

Downstream connection information.

---

##### `session`<sup>Required</sup> <a name="session" id="@wasend/core.SessionListItem.property.session"></a>

```typescript
public readonly session: SessionDetails;
```

- *Type:* <a href="#@wasend/core.SessionDetails">SessionDetails</a>

Session details.

---

### SessionMetadata <a name="SessionMetadata" id="@wasend/core.SessionMetadata"></a>

#### Initializer <a name="Initializer" id="@wasend/core.SessionMetadata.Initializer"></a>

```typescript
import { SessionMetadata } from '@wasend/core'

const sessionMetadata: SessionMetadata = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.SessionMetadata.property.userEmail">userEmail</a></code> | <code>string</code> | *No description.* |
| <code><a href="#@wasend/core.SessionMetadata.property.userId">userId</a></code> | <code>string</code> | *No description.* |

---

##### `userEmail`<sup>Required</sup> <a name="userEmail" id="@wasend/core.SessionMetadata.property.userEmail"></a>

```typescript
public readonly userEmail: string;
```

- *Type:* string

---

##### `userId`<sup>Required</sup> <a name="userId" id="@wasend/core.SessionMetadata.property.userId"></a>

```typescript
public readonly userId: string;
```

- *Type:* string

---

### WasendConfig <a name="WasendConfig" id="@wasend/core.WasendConfig"></a>

Configuration options for the Wasend SDK.

#### Initializer <a name="Initializer" id="@wasend/core.WasendConfig.Initializer"></a>

```typescript
import { WasendConfig } from '@wasend/core'

const wasendConfig: WasendConfig = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.WasendConfig.property.apiKey">apiKey</a></code> | <code>string</code> | The API key for authentication. |
| <code><a href="#@wasend/core.WasendConfig.property.baseUrl">baseUrl</a></code> | <code>string</code> | The base URL for the API (optional). |
| <code><a href="#@wasend/core.WasendConfig.property.timeout">timeout</a></code> | <code>number</code> | Request timeout in milliseconds. |

---

##### `apiKey`<sup>Required</sup> <a name="apiKey" id="@wasend/core.WasendConfig.property.apiKey"></a>

```typescript
public readonly apiKey: string;
```

- *Type:* string

The API key for authentication.

---

##### `baseUrl`<sup>Optional</sup> <a name="baseUrl" id="@wasend/core.WasendConfig.property.baseUrl"></a>

```typescript
public readonly baseUrl: string;
```

- *Type:* string
- *Default:* https://api.wasend.dev

The base URL for the API (optional).

---

##### `timeout`<sup>Optional</sup> <a name="timeout" id="@wasend/core.WasendConfig.property.timeout"></a>

```typescript
public readonly timeout: number;
```

- *Type:* number
- *Default:* 30000

Request timeout in milliseconds.

---

### WasendConfigInfo <a name="WasendConfigInfo" id="@wasend/core.WasendConfigInfo"></a>

Configuration information (without sensitive data).

#### Initializer <a name="Initializer" id="@wasend/core.WasendConfigInfo.Initializer"></a>

```typescript
import { WasendConfigInfo } from '@wasend/core'

const wasendConfigInfo: WasendConfigInfo = { ... }
```

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.WasendConfigInfo.property.baseUrl">baseUrl</a></code> | <code>string</code> | The base URL for the API. |
| <code><a href="#@wasend/core.WasendConfigInfo.property.timeout">timeout</a></code> | <code>number</code> | Request timeout in milliseconds. |

---

##### `baseUrl`<sup>Optional</sup> <a name="baseUrl" id="@wasend/core.WasendConfigInfo.property.baseUrl"></a>

```typescript
public readonly baseUrl: string;
```

- *Type:* string

The base URL for the API.

---

##### `timeout`<sup>Optional</sup> <a name="timeout" id="@wasend/core.WasendConfigInfo.property.timeout"></a>

```typescript
public readonly timeout: number;
```

- *Type:* number

Request timeout in milliseconds.

---

## Classes <a name="Classes" id="Classes"></a>

### WasendClient <a name="WasendClient" id="@wasend/core.WasendClient"></a>

Main Wasend SDK Client.

This class provides access to the Wasend API for sending messages,
managing contacts, and other messaging operations.

*Example*

```typescript
const client = new WasendClient({
  apiKey: 'your-api-key'
});

const result = await client.sendMessage({
  to: '+1234567890',
  content: 'Hello, World!'
});
```


#### Initializers <a name="Initializers" id="@wasend/core.WasendClient.Initializer"></a>

```typescript
import { WasendClient } from '@wasend/core'

new WasendClient(config: WasendConfig)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#@wasend/core.WasendClient.Initializer.parameter.config">config</a></code> | <code><a href="#@wasend/core.WasendConfig">WasendConfig</a></code> | - Configuration options for the client. |

---

##### `config`<sup>Required</sup> <a name="config" id="@wasend/core.WasendClient.Initializer.parameter.config"></a>

- *Type:* <a href="#@wasend/core.WasendConfig">WasendConfig</a>

Configuration options for the client.

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@wasend/core.WasendClient.createSession">createSession</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.deleteSession">deleteSession</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.getMessage">getMessage</a></code> | Get message by ID. |
| <code><a href="#@wasend/core.WasendClient.restartSession">restartSession</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.retrieveAccount">retrieveAccount</a></code> | Get account information. |
| <code><a href="#@wasend/core.WasendClient.retrieveAllSessions">retrieveAllSessions</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.retrieveConfig">retrieveConfig</a></code> | Get the current configuration. |
| <code><a href="#@wasend/core.WasendClient.retrieveQRCode">retrieveQRCode</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.retrieveSessionInfo">retrieveSessionInfo</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.sendMessage">sendMessage</a></code> | Send a message to a recipient. |
| <code><a href="#@wasend/core.WasendClient.startSession">startSession</a></code> | *No description.* |
| <code><a href="#@wasend/core.WasendClient.stopSession">stopSession</a></code> | *No description.* |

---

##### `createSession` <a name="createSession" id="@wasend/core.WasendClient.createSession"></a>

```typescript
public createSession(request: SessionCreateRequest): Session
```

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.createSession.parameter.request"></a>

- *Type:* <a href="#@wasend/core.SessionCreateRequest">SessionCreateRequest</a>

---

##### `deleteSession` <a name="deleteSession" id="@wasend/core.WasendClient.deleteSession"></a>

```typescript
public deleteSession(sessionId: string): void
```

###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.deleteSession.parameter.sessionId"></a>

- *Type:* string

---

##### `getMessage` <a name="getMessage" id="@wasend/core.WasendClient.getMessage"></a>

```typescript
public getMessage(messageId: string): ApiResponse
```

Get message by ID.

###### `messageId`<sup>Required</sup> <a name="messageId" id="@wasend/core.WasendClient.getMessage.parameter.messageId"></a>

- *Type:* string

The ID of the message to retrieve.

---

##### `restartSession` <a name="restartSession" id="@wasend/core.WasendClient.restartSession"></a>

```typescript
public restartSession(sessionId: string): Session
```

###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.restartSession.parameter.sessionId"></a>

- *Type:* string

---

##### `retrieveAccount` <a name="retrieveAccount" id="@wasend/core.WasendClient.retrieveAccount"></a>

```typescript
public retrieveAccount(): ApiResponse
```

Get account information.

##### `retrieveAllSessions` <a name="retrieveAllSessions" id="@wasend/core.WasendClient.retrieveAllSessions"></a>

```typescript
public retrieveAllSessions(): GetAllSessionsResponse
```

##### `retrieveConfig` <a name="retrieveConfig" id="@wasend/core.WasendClient.retrieveConfig"></a>

```typescript
public retrieveConfig(): WasendConfigInfo
```

Get the current configuration.

##### `retrieveQRCode` <a name="retrieveQRCode" id="@wasend/core.WasendClient.retrieveQRCode"></a>

```typescript
public retrieveQRCode(sessionId: string): QRCodeResponse
```

###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.retrieveQRCode.parameter.sessionId"></a>

- *Type:* string

---

##### `retrieveSessionInfo` <a name="retrieveSessionInfo" id="@wasend/core.WasendClient.retrieveSessionInfo"></a>

```typescript
public retrieveSessionInfo(sessionId: string): Session
```

###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.retrieveSessionInfo.parameter.sessionId"></a>

- *Type:* string

---

##### `sendMessage` <a name="sendMessage" id="@wasend/core.WasendClient.sendMessage"></a>

```typescript
public sendMessage(request: MessageRequest): ApiResponse
```

Send a message to a recipient.

###### `request`<sup>Required</sup> <a name="request" id="@wasend/core.WasendClient.sendMessage.parameter.request"></a>

- *Type:* <a href="#@wasend/core.MessageRequest">MessageRequest</a>

The message to send.

---

##### `startSession` <a name="startSession" id="@wasend/core.WasendClient.startSession"></a>

```typescript
public startSession(sessionId: string): Session
```

###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.startSession.parameter.sessionId"></a>

- *Type:* string

---

##### `stopSession` <a name="stopSession" id="@wasend/core.WasendClient.stopSession"></a>

```typescript
public stopSession(sessionId: string): Session
```

###### `sessionId`<sup>Required</sup> <a name="sessionId" id="@wasend/core.WasendClient.stopSession.parameter.sessionId"></a>

- *Type:* string

---




### WasendUtils <a name="WasendUtils" id="@wasend/core.WasendUtils"></a>

Utility functions for the Wasend SDK.

#### Initializers <a name="Initializers" id="@wasend/core.WasendUtils.Initializer"></a>

```typescript
import { WasendUtils } from '@wasend/core'

new WasendUtils()
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |

---


#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#@wasend/core.WasendUtils.formatPhoneNumber">formatPhoneNumber</a></code> | Format a phone number to international format. |
| <code><a href="#@wasend/core.WasendUtils.isValidPhoneNumber">isValidPhoneNumber</a></code> | Check if a phone number is valid. |

---

##### `formatPhoneNumber` <a name="formatPhoneNumber" id="@wasend/core.WasendUtils.formatPhoneNumber"></a>

```typescript
import { WasendUtils } from '@wasend/core'

WasendUtils.formatPhoneNumber(phoneNumber: string, countryCode?: string)
```

Format a phone number to international format.

###### `phoneNumber`<sup>Required</sup> <a name="phoneNumber" id="@wasend/core.WasendUtils.formatPhoneNumber.parameter.phoneNumber"></a>

- *Type:* string

The phone number to format.

---

###### `countryCode`<sup>Optional</sup> <a name="countryCode" id="@wasend/core.WasendUtils.formatPhoneNumber.parameter.countryCode"></a>

- *Type:* string

Optional country code to use.

---

##### `isValidPhoneNumber` <a name="isValidPhoneNumber" id="@wasend/core.WasendUtils.isValidPhoneNumber"></a>

```typescript
import { WasendUtils } from '@wasend/core'

WasendUtils.isValidPhoneNumber(phoneNumber: string)
```

Check if a phone number is valid.

###### `phoneNumber`<sup>Required</sup> <a name="phoneNumber" id="@wasend/core.WasendUtils.isValidPhoneNumber.parameter.phoneNumber"></a>

- *Type:* string

The phone number to validate.

---




